@@ -112,11 +112,13 @@ def max_sim(model, document_vec, concept_vec):
     comparisons = 0
     start_time = time.time()
     for term_1 in document_vec:
-        max_similarity = 0.0
+        max_similarity = 0
         matched_term = None
         for term_2 in concept_vec:
             comparisons += 1
             current_similarity = model.similarity(term_1, term_2)
+            if current_similarity <0:
+                current_similarity=0
             if current_similarity > max_similarity:
                 max_similarity = current_similarity
                 matched_term = term_2
@@ -145,6 +147,11 @@ p=None
 esa_matrix=None
 model=None
 concepts=None
+def normalize(esa_matrix):
+    for concept in esa_matrix:
+        concept_norm= norm(esa_matrix[concept])
+        for term in esa_matrix[concept]:
+            esa_matrix[concept][term]=esa_matrix[concept][term]/concept_norm
 
 def initialize_model(path_corpus,path_model,path_model_vocab,n):
     global p
@@ -162,6 +169,7 @@ def initialize_model(path_corpus,path_model,path_model_vocab,n):
         tfidf = compute_tfidf(tf, idfs, terms)
         top_n = get_top_terms(tfidf, n)
         esa_matrix = get_esa_matrix(top_n, tfidf, concepts)
+        normalize(esa_matrix)
         model = gensim.models.keyedvectors.KeyedVectors.load_word2vec_format(path_model, binary = True)
 
 def model_topic(path_corpus,path_model,path_model_vocab,text,n):
